# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`erlang`](#erlang): Manages the Erlang repository and package installation.
* [`erlang::repo`](#erlang--repo): Class that manages the erlang repo
* [`erlang::repo::apt`](#erlang--repo--apt): erlang apt repo
* [`erlang::repo::apt::erlang_solutions`](#erlang--repo--apt--erlang_solutions): erlang erlang_solutions apt repo
* [`erlang::repo::yum`](#erlang--repo--yum): erlang yum repo
* [`erlang::repo::yum::epel`](#erlang--repo--yum--epel): Erlang packagecloud yum repo
* [`erlang::repo::yum::erlang_solutions`](#erlang--repo--yum--erlang_solutions): Erlang packagecloud yum repo
* [`erlang::repo::yum::packagecloud`](#erlang--repo--yum--packagecloud): Erlang packagecloud yum repo

### Data types

* [`Erlang::RepoSource`](#Erlang--RepoSource): Options for what Erlang package repository to be configured on the system. This type defines the union of all possible options for both Apt a

## Classes

### <a name="erlang"></a>`erlang`

This class supports installing an Erlang repo on Debian/Ubuntu and CentOS/RHEL systems.
For Debian/Ubuntu an Apt package repository is configured.
For CentOS/RHEL a Yum package repository is configured.

There are several different package repositories sources available for installing Erlang,
each with their own pros/cons. Instead of being opinionated, we allow the user the option
to choose which repository source they would like to enable via the `repo_source` parameter.
This list was obtained from the official RabbitMQ documentation:
 - https://www.rabbitmq.com/install-debian.html#erlang-repositories
 - https://www.rabbitmq.com/install-rpm.html#install-erlang

See the documentation for the `repo_source` parameter for more information.

#### Examples

##### Basic usage for installing Erlang quick and easy

```puppet
include erlang
```

##### Configuring a different repo source, Erlang Solutions

```puppet
class { 'erlang':
  repo_source => 'erlang_solutions',
}
```

##### Configuring a different repo source, EPEL on CentOS/RHEL

```puppet
class { 'erlang':
  repo_source => 'epel',
}
```

##### Removing the erlang package and its repository

```puppet
class { 'erlang':
  package_ensure => 'absent',
  repo_ensure    => 'absent',
}
```

#### Parameters

The following parameters are available in the `erlang` class:

* [`package_name`](#-erlang--package_name)
* [`package_ensure`](#-erlang--package_ensure)
* [`package_apt_pin`](#-erlang--package_apt_pin)
* [`manage_repo`](#-erlang--manage_repo)
* [`repo_ensure`](#-erlang--repo_ensure)
* [`repo_source`](#-erlang--repo_source)

##### <a name="-erlang--package_name"></a>`package_name`

Data type: `String`

Name of the erlang package to install

Default value: `'erlang'`

##### <a name="-erlang--package_ensure"></a>`package_ensure`

Data type: `String`

Determines the ensure state of the package.  Set to installed by default, but could be changed to latest.

Default value: `'installed'`

##### <a name="-erlang--package_apt_pin"></a>`package_apt_pin`

Data type: `Optional[Variant[Numeric, String]]`

Whether to pin the package to a particular source.

Default value: `undef`

##### <a name="-erlang--manage_repo"></a>`manage_repo`

Data type: `Boolean`

Whether or not this class should manage the erlang repository.

Default value: `true`

##### <a name="-erlang--repo_ensure"></a>`repo_ensure`

Data type: `String`

Determines the ensure state of the repo.

Default value: `'present'`

##### <a name="-erlang--repo_source"></a>`repo_source`

Data type: `Erlang::RepoSource`

Determines what repository source should be configured for installing Erlang.
For Debian/Ubuntu the choices for `repo_source` are:
 - `'erlang_solutions'`

For CentOS/RHEL the choices for `repo_source` are:
 - `'epel'`
 - `'erlang_solutions'`
 - `'packagecloud'` (default)

Default value: `'packagecloud'`

### <a name="erlang--repo"></a>`erlang::repo`

Class that manages the erlang repo

### <a name="erlang--repo--apt"></a>`erlang::repo::apt`

erlang apt repo

#### Parameters

The following parameters are available in the `erlang::repo::apt` class:

* [`ensure`](#-erlang--repo--apt--ensure)
* [`source`](#-erlang--repo--apt--source)

##### <a name="-erlang--repo--apt--ensure"></a>`ensure`

Data type: `String`



Default value: `$erlang::repo_ensure`

##### <a name="-erlang--repo--apt--source"></a>`source`

Data type: `Erlang::RepoSource`



Default value: `$erlang::repo_source`

### <a name="erlang--repo--apt--erlang_solutions"></a>`erlang::repo::apt::erlang_solutions`

erlang erlang_solutions apt repo

#### Parameters

The following parameters are available in the `erlang::repo::apt::erlang_solutions` class:

* [`ensure`](#-erlang--repo--apt--erlang_solutions--ensure)
* [`location`](#-erlang--repo--apt--erlang_solutions--location)
* [`release`](#-erlang--repo--apt--erlang_solutions--release)
* [`repos`](#-erlang--repo--apt--erlang_solutions--repos)
* [`key`](#-erlang--repo--apt--erlang_solutions--key)
* [`key_source`](#-erlang--repo--apt--erlang_solutions--key_source)
* [`pin`](#-erlang--repo--apt--erlang_solutions--pin)

##### <a name="-erlang--repo--apt--erlang_solutions--ensure"></a>`ensure`

Data type: `String`



Default value: `$erlang::repo::apt::ensure`

##### <a name="-erlang--repo--apt--erlang_solutions--location"></a>`location`

Data type: `String`



Default value: `'https://packages.erlang-solutions.com/debian'`

##### <a name="-erlang--repo--apt--erlang_solutions--release"></a>`release`

Data type: `String`



Default value: `downcase($facts['os']['distro']['codename'])`

##### <a name="-erlang--repo--apt--erlang_solutions--repos"></a>`repos`

Data type: `String`



Default value: `'contrib'`

##### <a name="-erlang--repo--apt--erlang_solutions--key"></a>`key`

Data type: `String`



Default value: `'434975BD900CCBE4F7EE1B1ED208507CA14F4FCA'`

##### <a name="-erlang--repo--apt--erlang_solutions--key_source"></a>`key_source`

Data type: `String`



Default value: `'https://packages.erlang-solutions.com/debian/erlang_solutions.asc'`

##### <a name="-erlang--repo--apt--erlang_solutions--pin"></a>`pin`

Data type: `Optional[Variant[Numeric, String]]`



Default value: `$erlang::package_apt_pin`

### <a name="erlang--repo--yum"></a>`erlang::repo::yum`

erlang yum repo

#### Parameters

The following parameters are available in the `erlang::repo::yum` class:

* [`ensure`](#-erlang--repo--yum--ensure)
* [`source`](#-erlang--repo--yum--source)

##### <a name="-erlang--repo--yum--ensure"></a>`ensure`

Data type: `String`



Default value: `$erlang::repo_ensure`

##### <a name="-erlang--repo--yum--source"></a>`source`

Data type: `Erlang::RepoSource`



Default value: `$erlang::repo_source`

### <a name="erlang--repo--yum--epel"></a>`erlang::repo::yum::epel`

Erlang packagecloud yum repo

### <a name="erlang--repo--yum--erlang_solutions"></a>`erlang::repo::yum::erlang_solutions`

Erlang packagecloud yum repo

#### Parameters

The following parameters are available in the `erlang::repo::yum::erlang_solutions` class:

* [`ensure`](#-erlang--repo--yum--erlang_solutions--ensure)
* [`baseurl`](#-erlang--repo--yum--erlang_solutions--baseurl)
* [`gpgkey`](#-erlang--repo--yum--erlang_solutions--gpgkey)

##### <a name="-erlang--repo--yum--erlang_solutions--ensure"></a>`ensure`

Data type: `String`



Default value: `$erlang::repo::yum::ensure`

##### <a name="-erlang--repo--yum--erlang_solutions--baseurl"></a>`baseurl`

Data type: `String`



Default value: `"https://packages.erlang-solutions.com/rpm/centos/\$releasever/\$basearch"`

##### <a name="-erlang--repo--yum--erlang_solutions--gpgkey"></a>`gpgkey`

Data type: `String`



Default value: `'https://packages.erlang-solutions.com/rpm/erlang_solutions.asc'`

### <a name="erlang--repo--yum--packagecloud"></a>`erlang::repo::yum::packagecloud`

Erlang packagecloud yum repo

#### Parameters

The following parameters are available in the `erlang::repo::yum::packagecloud` class:

* [`ensure`](#-erlang--repo--yum--packagecloud--ensure)
* [`baseurl`](#-erlang--repo--yum--packagecloud--baseurl)
* [`gpgkey`](#-erlang--repo--yum--packagecloud--gpgkey)

##### <a name="-erlang--repo--yum--packagecloud--ensure"></a>`ensure`

Data type: `String`



Default value: `$erlang::repo::yum::ensure`

##### <a name="-erlang--repo--yum--packagecloud--baseurl"></a>`baseurl`

Data type: `String`



Default value: `"https://packagecloud.io/rabbitmq/erlang/el/${$facts['os']['release']['major']}/\$basearch"`

##### <a name="-erlang--repo--yum--packagecloud--gpgkey"></a>`gpgkey`

Data type: `String`



Default value: `'https://packagecloud.io/rabbitmq/erlang/gpgkey'`

## Data types

### <a name="Erlang--RepoSource"></a>`Erlang::RepoSource`

Options for what Erlang package repository to be configured on the system.
This type defines the union of all possible options for both Apt and Yum repos.
However, each OS family has a different subset of requirements:
For Debian/Ubuntu the choices for `repo_source` are:
 - `'bintray'` (default)
 - `'erlang_solutions'`

For CentOS/RHEL the choices for `repo_source` are:
 - `'bintray'`
 - `'epel'`
 - `'erlang_solutions'`
 - `'packagecloud'` (default)

Alias of `Enum['epel', 'erlang_solutions', 'packagecloud']`

